@@ -1,9 +1,9 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2019 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2019-2024 -- leonerd@leonerd.org.uk
 
-package Devel::MAT::Tool::Stack 0.52;
+package Devel::MAT::Tool::Stack 0.53;
 
 use v5.14;
 use warnings;
@@ -49,4 +49,10 @@ sub run
    }
 }
 
+=head1 AUTHOR
+
+Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
 0x55AA;
